Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrEmptyResponse is returned when the response body is empty ErrEmptyResponse = fmt.Errorf("empty response body") // ErrHTTPError is returned when the HTTP request fails ErrHTTPError = fmt.Errorf("HTTP request failed") // ErrUnexpectedStatusCode is returned when the HTTP status code is not 200 ErrUnexpectedStatusCode = fmt.Errorf("unexpected status code") // ErrMaxRetriesExceeded is returned when the maximum number of retries is exceeded ErrMaxRetriesExceeded = fmt.Errorf("exceeded maximum retries while waiting for BGG to process request") // ErrUnmarshalError is returned when the XML response cannot be unmarshalled ErrUnmarshalError = fmt.Errorf("failed to unmarshal XML response") // ErrRegenerateError is returned when the XML response cannot be regenerated ErrRegenerateError = fmt.Errorf("failed to regenerate XML response") // ErrXMLParseError is returned when the XML response cannot be parsed ErrXMLParseError = fmt.Errorf("failed to parse XML response") )
Functions ¶
func FetchAndUnmarshal ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.